==> haskell-html-conduit-1.3.2.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.2.1
id: html-conduit-1.3.2.1-GBpLcZjnqgH9ofxgqWzxhk
key: html-conduit-1.3.2.1-GBpLcZjnqgH9ofxgqWzxhk
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: a612284c6c773457d36dc8e564f6ce22
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/html-conduit-1.3.2.1
hs-libraries: HShtml-conduit-1.3.2.1-GBpLcZjnqgH9ofxgqWzxhk
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-7uQvxkXSawE7t4T2ZzYFLO
    conduit-extra-1.3.4-JI5NsG2ZqVlCBe03fnfqWX containers-0.6.0.1
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-8nGtUq5Zr565BZV1XGgZPO
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.2.1
id: html-conduit-1.3.2.1-giDjYrufcZI6c4ftvVxFm
key: html-conduit-1.3.2.1-giDjYrufcZI6c4ftvVxFm
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 031f17e4d32b2c1ca1a817b6d20db3b4
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/html-conduit-1.3.2.1
hs-libraries: HShtml-conduit-1.3.2.1-giDjYrufcZI6c4ftvVxFm
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-KLNDZz0JwjY8UxgeaedHmp
    conduit-extra-1.3.4-D0NpH8QgZ19ARuWPauoeRr containers-0.6.0.1
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-ItKMKBLRSqtFuvW7keDBPV
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
